==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>Reproductor multimedia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Configuración de MPD</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Dirección del servidor MPD</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Número de puerto que MPD está escuchando</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Tiempo de espera de conexión (segundos)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Número de segundos antes que la conexión sea terminada</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/mpd_mediaplayer/translations/mpd_mediaplayer_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>Reproductor multimedia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Media Player Daemon Settings</source>
        <translation>Configuración de MPD</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Media Player Daemon server address</source>
        <translation>Dirección del servidor MPD</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Port number MPD is listening on</source>
        <translation>Número de puerto que MPD está escuchando</translation>
    </message>
    <message>
        <source>Connection timeout (seconds)</source>
        <translation>Tiempo de espera de conexión (segundos)</translation>
    </message>
    <message>
        <source>Number of seconds before the connection is terminated</source>
        <translation>Número de segundos antes que la conexión sea terminada</translation>
    </message>
</context>
<context>
    <name>MPDMediaPlayer</name>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
</TS>
